==> deepin-camera_6.5.23.tar.xz: BUILD/src/translations/deepin-camera_hr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hr">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Video snimanje je u tijeku. Zatvoriti prozor?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Otvori mapu</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <source>None</source>
        <translation>NIjedan</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Фото</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Prebacite kamera</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zatvori</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otvori mapu</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Ispis</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Nemate dozvolu za rad s ovom mapom</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Neispravna mapa</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otvori mapu</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Osnovno</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Lokacija datoteke</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Snimi</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Mod strujanja</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Zakaži zaštitni vremenski odziv</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Izlaz</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Format izlaza</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 komada</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 komada</translation>
    </message>
    <message>
        <source>None</source>
        <translation>NIjedan</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera je alat za prikupljanje slika i video sadržaja koristeći vašu računarsku kameru ili web kamere.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Datoteka nije spremljena</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Spremi u:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Fotografija:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Postavke razlučivosti</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Razlučivost:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotografije:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videa:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Zvučni efekti</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Mod ogledala</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Fotokamera</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Rasponi</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1×1 linije</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2×2 linije</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Maksimalna rezolucija:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Prestani snimati</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otvori</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Ispis</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Prikaži prečace</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Prestani fotografirati</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Kontekstualni izbornik</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Fotografiraj</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Snimi video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Prestani fotografirati</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>NIjedan</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normalan</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Živahni</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Top</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Hladan</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Sivo</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>B&amp;W</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Fotokamera</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Uključen</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Isključen</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Zakaži snimanje</translation>
    </message>
    <message>
        <source>None</source>
        <translation>NIjedan</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filteri</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Izlaganje</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Web kamera nije nađena</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Web kamera je u uporabi</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Prestani snimati</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.35.tar.xz: BUILD/src/translations/deepin-camera_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Video snimanje je u tijeku. Zatvoriti prozor?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Otvori mapu</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <source>None</source>
        <translation>NIjedan</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Slika</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Prebaciti kamere</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zatvori</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otvori mapu</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Ispis</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Nemate dopuštenje za rad u ovom folderu</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Neispravna mapa</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otvori mapu</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Osnovno</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Lokacija datoteke</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Snimi</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Režim serije</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Zadnji odziv</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Izlaz</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Format izlaza</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 komada</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 komada</translation>
    </message>
    <message>
        <source>None</source>
        <translation>NIjedan</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera je alat za snimanje slika i videa koristeći vašu računarsku kameru ili webkameru.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Datoteka nije spremljena</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Spremi u:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Fotografija:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Postavke razlučivosti</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Razlučivost:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotografije:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videa:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Zvučni efekti</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Zrcalni režim</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Reflektor</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Mreža</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1 linije</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2 linije</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Maksimalna rezolucija:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Prestani snimati</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otvori</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Ispis</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Prikaži prečace</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Prestani fotografirati</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Kontekstualni izbornik</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Fotografiraj</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Snimi video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Prestani fotografirati</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>NIjedan</translation>
    </message>
    <message>
        <source>mp4</source>
        <translation>mp4</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normalan</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Živahan</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Top</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Hladan</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Siva</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>B&amp;W</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Reflektor</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Uključen</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Isključeno</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Zadliječi snimanje</translation>
    </message>
    <message>
        <source>None</source>
        <translation>NIjedan</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filteri</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Osvetljenje</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Web kamera nije nađena</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Web kamera je u uporabi</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Prestani snimati</translation>
    </message>
</context>
</TS>
